@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2018 Losant IoT, Inc.
+Copyright (c) 2020 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -31,8 +31,13 @@ import sys
 from .application import Application
 from .application_api_token import ApplicationApiToken
 from .application_api_tokens import ApplicationApiTokens
+from .application_certificate import ApplicationCertificate
+from .application_certificate_authorities import ApplicationCertificateAuthorities
+from .application_certificate_authority import ApplicationCertificateAuthority
+from .application_certificates import ApplicationCertificates
 from .application_key import ApplicationKey
 from .application_keys import ApplicationKeys
+from .application_templates import ApplicationTemplates
 from .applications import Applications
 from .audit_log import AuditLog
 from .audit_logs import AuditLogs
@@ -75,13 +80,11 @@ from .flows import Flows
 from .integration import Integration
 from .integrations import Integrations
 from .me import Me
+from .notebook import Notebook
+from .notebooks import Notebooks
 from .org import Org
 from .org_invites import OrgInvites
 from .orgs import Orgs
-from .solution import Solution
-from .solution_user import SolutionUser
-from .solution_users import SolutionUsers
-from .solutions import Solutions
 from .webhook import Webhook
 from .webhooks import Webhooks
 from .losant_error import LosantError
@@ -95,7 +98,7 @@ class Client(object):
 
     User API for accessing Losant data
 
-    Built For Version 1.13.3
+    Built For Version 1.17.0
     """
 
     def __init__(self, auth_token=None, url="https://api.losant.com"):
@@ -104,8 +107,13 @@ class Client(object):
         self.application = Application(self)
         self.application_api_token = ApplicationApiToken(self)
         self.application_api_tokens = ApplicationApiTokens(self)
+        self.application_certificate = ApplicationCertificate(self)
+        self.application_certificate_authorities = ApplicationCertificateAuthorities(self)
+        self.application_certificate_authority = ApplicationCertificateAuthority(self)
+        self.application_certificates = ApplicationCertificates(self)
         self.application_key = ApplicationKey(self)
         self.application_keys = ApplicationKeys(self)
+        self.application_templates = ApplicationTemplates(self)
         self.applications = Applications(self)
         self.audit_log = AuditLog(self)
         self.audit_logs = AuditLogs(self)
@@ -148,13 +156,11 @@ class Client(object):
         self.integration = Integration(self)
         self.integrations = Integrations(self)
         self.me = Me(self)
+        self.notebook = Notebook(self)
+        self.notebooks = Notebooks(self)
         self.org = Org(self)
         self.org_invites = OrgInvites(self)
         self.orgs = Orgs(self)
-        self.solution = Solution(self)
-        self.solution_user = SolutionUser(self)
-        self.solution_users = SolutionUsers(self)
-        self.solutions = Solutions(self)
         self.webhook = Webhook(self)
         self.webhooks = Webhooks(self)
 
@@ -166,7 +172,7 @@ class Client(object):
             params = {}
 
         headers["Accept"] = "application/json"
-        headers["Accept-Version"] = "^1.13.3"
+        headers["Accept-Version"] = "^1.17.0"
         if self.auth_token:
             headers["Authorization"] = "Bearer {0}".format(self.auth_token)
 
